# This file was auto-generated by Fern from our API Definition.

import typing

from ...core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ...core.request_options import RequestOptions
from ...types.configurable_permission_option import ConfigurablePermissionOption
from ...types.organization_permission import OrganizationPermission
from ...types.role9e7enum import Role9E7Enum
from .raw_client import AsyncRawPermissionsClient, RawPermissionsClient

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class PermissionsClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawPermissionsClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawPermissionsClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawPermissionsClient
        """
        return self._raw_client

    def list(
        self, id: int, *, ordering: typing.Optional[str] = None, request_options: typing.Optional[RequestOptions] = None
    ) -> typing.List[OrganizationPermission]:
        """
        <Card href="https://humansignal.com/goenterprise">
                <img style="pointer-events: none; margin-left: 0px; margin-right: 0px;" src="https://docs.humansignal.com/images/badge.svg" alt="Label Studio Enterprise badge"/>
                <p style="margin-top: 10px; font-size: 14px;">
                    This endpoint is not available in Label Studio Community Edition. [Learn more about Label Studio Enterprise](https://humansignal.com/goenterprise)
                </p>
            </Card>
        List all organization-level permission overrides for a given organization.

        Parameters
        ----------
        id : int

        ordering : typing.Optional[str]
            Which field to use when ordering the results.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.List[OrganizationPermission]


        Examples
        --------
        from label_studio_sdk import LabelStudio

        client = LabelStudio(
            api_key="YOUR_API_KEY",
        )
        client.organizations.permissions.list(
            id=1,
        )
        """
        _response = self._raw_client.list(id, ordering=ordering, request_options=request_options)
        return _response.data

    def create(
        self,
        id: int,
        *,
        permission: str,
        roles: typing.Optional[typing.Sequence[Role9E7Enum]] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> OrganizationPermission:
        """
        <Card href="https://humansignal.com/goenterprise">
                <img style="pointer-events: none; margin-left: 0px; margin-right: 0px;" src="https://docs.humansignal.com/images/badge.svg" alt="Label Studio Enterprise badge"/>
                <p style="margin-top: 10px; font-size: 14px;">
                    This endpoint is not available in Label Studio Community Edition. [Learn more about Label Studio Enterprise](https://humansignal.com/goenterprise)
                </p>
            </Card>
        Create a new organization-level permission override for a given organization.

        Parameters
        ----------
        id : int

        permission : str

        roles : typing.Optional[typing.Sequence[Role9E7Enum]]
            Explicit roles that have this permission within the organization.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        OrganizationPermission


        Examples
        --------
        from label_studio_sdk import LabelStudio

        client = LabelStudio(
            api_key="YOUR_API_KEY",
        )
        client.organizations.permissions.create(
            id=1,
            permission="permission",
        )
        """
        _response = self._raw_client.create(id, permission=permission, roles=roles, request_options=request_options)
        return _response.data

    def get_options(
        self, id: int, *, ordering: typing.Optional[str] = None, request_options: typing.Optional[RequestOptions] = None
    ) -> typing.List[ConfigurablePermissionOption]:
        """
        <Card href="https://humansignal.com/goenterprise">
                <img style="pointer-events: none; margin-left: 0px; margin-right: 0px;" src="https://docs.humansignal.com/images/badge.svg" alt="Label Studio Enterprise badge"/>
                <p style="margin-top: 10px; font-size: 14px;">
                    This endpoint is not available in Label Studio Community Edition. [Learn more about Label Studio Enterprise](https://humansignal.com/goenterprise)
                </p>
            </Card>
        Retrieve the list of configurable permission options (label, tooltip, default role and allowed roles).

        Parameters
        ----------
        id : int

        ordering : typing.Optional[str]
            Which field to use when ordering the results.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.List[ConfigurablePermissionOption]


        Examples
        --------
        from label_studio_sdk import LabelStudio

        client = LabelStudio(
            api_key="YOUR_API_KEY",
        )
        client.organizations.permissions.get_options(
            id=1,
        )
        """
        _response = self._raw_client.get_options(id, ordering=ordering, request_options=request_options)
        return _response.data

    def get(
        self, id: int, permission: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> OrganizationPermission:
        """
        <Card href="https://humansignal.com/goenterprise">
                <img style="pointer-events: none; margin-left: 0px; margin-right: 0px;" src="https://docs.humansignal.com/images/badge.svg" alt="Label Studio Enterprise badge"/>
                <p style="margin-top: 10px; font-size: 14px;">
                    This endpoint is not available in Label Studio Community Edition. [Learn more about Label Studio Enterprise](https://humansignal.com/goenterprise)
                </p>
            </Card>
        Retrieve the organization-level permission override for a given permission key.

        Parameters
        ----------
        id : int

        permission : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        OrganizationPermission


        Examples
        --------
        from label_studio_sdk import LabelStudio

        client = LabelStudio(
            api_key="YOUR_API_KEY",
        )
        client.organizations.permissions.get(
            id=1,
            permission="permission",
        )
        """
        _response = self._raw_client.get(id, permission, request_options=request_options)
        return _response.data

    def replace(
        self,
        id: int,
        permission_: str,
        *,
        permission: str,
        roles: typing.Optional[typing.Sequence[Role9E7Enum]] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> OrganizationPermission:
        """
        <Card href="https://humansignal.com/goenterprise">
                <img style="pointer-events: none; margin-left: 0px; margin-right: 0px;" src="https://docs.humansignal.com/images/badge.svg" alt="Label Studio Enterprise badge"/>
                <p style="margin-top: 10px; font-size: 14px;">
                    This endpoint is not available in Label Studio Community Edition. [Learn more about Label Studio Enterprise](https://humansignal.com/goenterprise)
                </p>
            </Card>
        Replace the organization-level permission override for a given permission key.

        Parameters
        ----------
        id : int
            A unique integer value identifying this organization.

        permission_ : str
            Permission key to update within the organization.

        permission : str

        roles : typing.Optional[typing.Sequence[Role9E7Enum]]
            Explicit roles that have this permission within the organization.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        OrganizationPermission


        Examples
        --------
        from label_studio_sdk import LabelStudio

        client = LabelStudio(
            api_key="YOUR_API_KEY",
        )
        client.organizations.permissions.replace(
            id=1,
            permission_="permission",
            permission="permission",
        )
        """
        _response = self._raw_client.replace(
            id, permission_, permission=permission, roles=roles, request_options=request_options
        )
        return _response.data

    def delete(self, id: int, permission: str, *, request_options: typing.Optional[RequestOptions] = None) -> None:
        """
        <Card href="https://humansignal.com/goenterprise">
                <img style="pointer-events: none; margin-left: 0px; margin-right: 0px;" src="https://docs.humansignal.com/images/badge.svg" alt="Label Studio Enterprise badge"/>
                <p style="margin-top: 10px; font-size: 14px;">
                    This endpoint is not available in Label Studio Community Edition. [Learn more about Label Studio Enterprise](https://humansignal.com/goenterprise)
                </p>
            </Card>
        Delete the organization-level permission override for a given permission key.

        Parameters
        ----------
        id : int

        permission : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        None

        Examples
        --------
        from label_studio_sdk import LabelStudio

        client = LabelStudio(
            api_key="YOUR_API_KEY",
        )
        client.organizations.permissions.delete(
            id=1,
            permission="permission",
        )
        """
        _response = self._raw_client.delete(id, permission, request_options=request_options)
        return _response.data

    def update(
        self,
        id: int,
        permission: str,
        *,
        patched_organization_permission_request_permission: typing.Optional[str] = OMIT,
        roles: typing.Optional[typing.Sequence[Role9E7Enum]] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> OrganizationPermission:
        """
        <Card href="https://humansignal.com/goenterprise">
                <img style="pointer-events: none; margin-left: 0px; margin-right: 0px;" src="https://docs.humansignal.com/images/badge.svg" alt="Label Studio Enterprise badge"/>
                <p style="margin-top: 10px; font-size: 14px;">
                    This endpoint is not available in Label Studio Community Edition. [Learn more about Label Studio Enterprise](https://humansignal.com/goenterprise)
                </p>
            </Card>
        Partially update the organization-level permission override for a given permission key.

        Parameters
        ----------
        id : int

        permission : str

        patched_organization_permission_request_permission : typing.Optional[str]

        roles : typing.Optional[typing.Sequence[Role9E7Enum]]
            Explicit roles that have this permission within the organization.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        OrganizationPermission


        Examples
        --------
        from label_studio_sdk import LabelStudio

        client = LabelStudio(
            api_key="YOUR_API_KEY",
        )
        client.organizations.permissions.update(
            id=1,
            permission="permission",
        )
        """
        _response = self._raw_client.update(
            id,
            permission,
            patched_organization_permission_request_permission=patched_organization_permission_request_permission,
            roles=roles,
            request_options=request_options,
        )
        return _response.data


class AsyncPermissionsClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawPermissionsClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawPermissionsClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawPermissionsClient
        """
        return self._raw_client

    async def list(
        self, id: int, *, ordering: typing.Optional[str] = None, request_options: typing.Optional[RequestOptions] = None
    ) -> typing.List[OrganizationPermission]:
        """
        <Card href="https://humansignal.com/goenterprise">
                <img style="pointer-events: none; margin-left: 0px; margin-right: 0px;" src="https://docs.humansignal.com/images/badge.svg" alt="Label Studio Enterprise badge"/>
                <p style="margin-top: 10px; font-size: 14px;">
                    This endpoint is not available in Label Studio Community Edition. [Learn more about Label Studio Enterprise](https://humansignal.com/goenterprise)
                </p>
            </Card>
        List all organization-level permission overrides for a given organization.

        Parameters
        ----------
        id : int

        ordering : typing.Optional[str]
            Which field to use when ordering the results.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.List[OrganizationPermission]


        Examples
        --------
        import asyncio

        from label_studio_sdk import AsyncLabelStudio

        client = AsyncLabelStudio(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.organizations.permissions.list(
                id=1,
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.list(id, ordering=ordering, request_options=request_options)
        return _response.data

    async def create(
        self,
        id: int,
        *,
        permission: str,
        roles: typing.Optional[typing.Sequence[Role9E7Enum]] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> OrganizationPermission:
        """
        <Card href="https://humansignal.com/goenterprise">
                <img style="pointer-events: none; margin-left: 0px; margin-right: 0px;" src="https://docs.humansignal.com/images/badge.svg" alt="Label Studio Enterprise badge"/>
                <p style="margin-top: 10px; font-size: 14px;">
                    This endpoint is not available in Label Studio Community Edition. [Learn more about Label Studio Enterprise](https://humansignal.com/goenterprise)
                </p>
            </Card>
        Create a new organization-level permission override for a given organization.

        Parameters
        ----------
        id : int

        permission : str

        roles : typing.Optional[typing.Sequence[Role9E7Enum]]
            Explicit roles that have this permission within the organization.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        OrganizationPermission


        Examples
        --------
        import asyncio

        from label_studio_sdk import AsyncLabelStudio

        client = AsyncLabelStudio(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.organizations.permissions.create(
                id=1,
                permission="permission",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.create(
            id, permission=permission, roles=roles, request_options=request_options
        )
        return _response.data

    async def get_options(
        self, id: int, *, ordering: typing.Optional[str] = None, request_options: typing.Optional[RequestOptions] = None
    ) -> typing.List[ConfigurablePermissionOption]:
        """
        <Card href="https://humansignal.com/goenterprise">
                <img style="pointer-events: none; margin-left: 0px; margin-right: 0px;" src="https://docs.humansignal.com/images/badge.svg" alt="Label Studio Enterprise badge"/>
                <p style="margin-top: 10px; font-size: 14px;">
                    This endpoint is not available in Label Studio Community Edition. [Learn more about Label Studio Enterprise](https://humansignal.com/goenterprise)
                </p>
            </Card>
        Retrieve the list of configurable permission options (label, tooltip, default role and allowed roles).

        Parameters
        ----------
        id : int

        ordering : typing.Optional[str]
            Which field to use when ordering the results.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.List[ConfigurablePermissionOption]


        Examples
        --------
        import asyncio

        from label_studio_sdk import AsyncLabelStudio

        client = AsyncLabelStudio(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.organizations.permissions.get_options(
                id=1,
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.get_options(id, ordering=ordering, request_options=request_options)
        return _response.data

    async def get(
        self, id: int, permission: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> OrganizationPermission:
        """
        <Card href="https://humansignal.com/goenterprise">
                <img style="pointer-events: none; margin-left: 0px; margin-right: 0px;" src="https://docs.humansignal.com/images/badge.svg" alt="Label Studio Enterprise badge"/>
                <p style="margin-top: 10px; font-size: 14px;">
                    This endpoint is not available in Label Studio Community Edition. [Learn more about Label Studio Enterprise](https://humansignal.com/goenterprise)
                </p>
            </Card>
        Retrieve the organization-level permission override for a given permission key.

        Parameters
        ----------
        id : int

        permission : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        OrganizationPermission


        Examples
        --------
        import asyncio

        from label_studio_sdk import AsyncLabelStudio

        client = AsyncLabelStudio(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.organizations.permissions.get(
                id=1,
                permission="permission",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.get(id, permission, request_options=request_options)
        return _response.data

    async def replace(
        self,
        id: int,
        permission_: str,
        *,
        permission: str,
        roles: typing.Optional[typing.Sequence[Role9E7Enum]] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> OrganizationPermission:
        """
        <Card href="https://humansignal.com/goenterprise">
                <img style="pointer-events: none; margin-left: 0px; margin-right: 0px;" src="https://docs.humansignal.com/images/badge.svg" alt="Label Studio Enterprise badge"/>
                <p style="margin-top: 10px; font-size: 14px;">
                    This endpoint is not available in Label Studio Community Edition. [Learn more about Label Studio Enterprise](https://humansignal.com/goenterprise)
                </p>
            </Card>
        Replace the organization-level permission override for a given permission key.

        Parameters
        ----------
        id : int
            A unique integer value identifying this organization.

        permission_ : str
            Permission key to update within the organization.

        permission : str

        roles : typing.Optional[typing.Sequence[Role9E7Enum]]
            Explicit roles that have this permission within the organization.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        OrganizationPermission


        Examples
        --------
        import asyncio

        from label_studio_sdk import AsyncLabelStudio

        client = AsyncLabelStudio(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.organizations.permissions.replace(
                id=1,
                permission_="permission",
                permission="permission",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.replace(
            id, permission_, permission=permission, roles=roles, request_options=request_options
        )
        return _response.data

    async def delete(
        self, id: int, permission: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> None:
        """
        <Card href="https://humansignal.com/goenterprise">
                <img style="pointer-events: none; margin-left: 0px; margin-right: 0px;" src="https://docs.humansignal.com/images/badge.svg" alt="Label Studio Enterprise badge"/>
                <p style="margin-top: 10px; font-size: 14px;">
                    This endpoint is not available in Label Studio Community Edition. [Learn more about Label Studio Enterprise](https://humansignal.com/goenterprise)
                </p>
            </Card>
        Delete the organization-level permission override for a given permission key.

        Parameters
        ----------
        id : int

        permission : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        None

        Examples
        --------
        import asyncio

        from label_studio_sdk import AsyncLabelStudio

        client = AsyncLabelStudio(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.organizations.permissions.delete(
                id=1,
                permission="permission",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.delete(id, permission, request_options=request_options)
        return _response.data

    async def update(
        self,
        id: int,
        permission: str,
        *,
        patched_organization_permission_request_permission: typing.Optional[str] = OMIT,
        roles: typing.Optional[typing.Sequence[Role9E7Enum]] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> OrganizationPermission:
        """
        <Card href="https://humansignal.com/goenterprise">
                <img style="pointer-events: none; margin-left: 0px; margin-right: 0px;" src="https://docs.humansignal.com/images/badge.svg" alt="Label Studio Enterprise badge"/>
                <p style="margin-top: 10px; font-size: 14px;">
                    This endpoint is not available in Label Studio Community Edition. [Learn more about Label Studio Enterprise](https://humansignal.com/goenterprise)
                </p>
            </Card>
        Partially update the organization-level permission override for a given permission key.

        Parameters
        ----------
        id : int

        permission : str

        patched_organization_permission_request_permission : typing.Optional[str]

        roles : typing.Optional[typing.Sequence[Role9E7Enum]]
            Explicit roles that have this permission within the organization.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        OrganizationPermission


        Examples
        --------
        import asyncio

        from label_studio_sdk import AsyncLabelStudio

        client = AsyncLabelStudio(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.organizations.permissions.update(
                id=1,
                permission="permission",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.update(
            id,
            permission,
            patched_organization_permission_request_permission=patched_organization_permission_request_permission,
            roles=roles,
            request_options=request_options,
        )
        return _response.data
